==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebMRLResizeColumnInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebMRLResizeColumnInfoDescription } from "./WebMRLResizeColumnInfoDescription";
/**
 * @hidden
 */
var WebMRLResizeColumnInfoDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebMRLResizeColumnInfoDescriptionMetadata, _super);
    function WebMRLResizeColumnInfoDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebMRLResizeColumnInfoDescriptionMetadata.b = function (a) {
        if (WebMRLResizeColumnInfoDescriptionMetadata.a == null) {
            WebMRLResizeColumnInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebMRLResizeColumnInfoDescriptionMetadata.c(WebMRLResizeColumnInfoDescriptionMetadata.a);
        }
        if (a.j(WebMRLResizeColumnInfoDescriptionMetadata.a)) {
            return;
        }
        a.y(WebMRLResizeColumnInfoDescriptionMetadata.a);
    };
    WebMRLResizeColumnInfoDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:MRLResizeColumnInfo");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
    };
    WebMRLResizeColumnInfoDescriptionMetadata.d = function (a) {
        WebMRLResizeColumnInfoDescriptionMetadata.b(a);
        a.aa("WebMRLResizeColumnInfo", function () { return new WebMRLResizeColumnInfoDescription(); });
        a.z("WebMRLResizeColumnInfo", WebMRLResizeColumnInfoDescriptionMetadata.a);
    };
    WebMRLResizeColumnInfoDescriptionMetadata.$t = markType(WebMRLResizeColumnInfoDescriptionMetadata, 'WebMRLResizeColumnInfoDescriptionMetadata');
    WebMRLResizeColumnInfoDescriptionMetadata.a = null;
    return WebMRLResizeColumnInfoDescriptionMetadata;
}(Base));
export { WebMRLResizeColumnInfoDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebMRLResizeColumnInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebMRLResizeColumnInfoDescription } from "./WebMRLResizeColumnInfoDescription";
/**
 * @hidden
 */
var WebMRLResizeColumnInfoDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebMRLResizeColumnInfoDescriptionMetadata, _super);
    function WebMRLResizeColumnInfoDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebMRLResizeColumnInfoDescriptionMetadata.b = function (a) {
        if (WebMRLResizeColumnInfoDescriptionMetadata.a == null) {
            WebMRLResizeColumnInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebMRLResizeColumnInfoDescriptionMetadata.c(WebMRLResizeColumnInfoDescriptionMetadata.a);
        }
        if (a.k(WebMRLResizeColumnInfoDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebMRLResizeColumnInfoDescriptionMetadata.a);
    };
    WebMRLResizeColumnInfoDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:MRLResizeColumnInfo");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
    };
    WebMRLResizeColumnInfoDescriptionMetadata.d = function (a) {
        WebMRLResizeColumnInfoDescriptionMetadata.b(a);
        a.ac("WebMRLResizeColumnInfo", function () { return new WebMRLResizeColumnInfoDescription(); });
        a.ab("WebMRLResizeColumnInfo", WebMRLResizeColumnInfoDescriptionMetadata.a);
    };
    WebMRLResizeColumnInfoDescriptionMetadata.$t = markType(WebMRLResizeColumnInfoDescriptionMetadata, 'WebMRLResizeColumnInfoDescriptionMetadata');
    WebMRLResizeColumnInfoDescriptionMetadata.a = null;
    return WebMRLResizeColumnInfoDescriptionMetadata;
}(Base));
export { WebMRLResizeColumnInfoDescriptionMetadata };
